@@ -11,7 +11,6 @@ import os
 import re
 
 import pytest
-import sphinx
 from docutils import VersionInfo, __version_info__
 
 SOURCE_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__), "sourcedirs"))
@@ -54,7 +53,7 @@ def test_basic(
         app,
         filename="content.html",
         regress_html=True,
-        regress_ext=f".sphinx{sphinx.version_info[0]}.html",
+        regress_ext=".html",
     )
 
     assert app.env.metadata["content"] == {
@@ -91,8 +90,12 @@ def test_references(
     app.build()
 
     assert "build succeeded" in status.getvalue()  # Build succeeded
-    warnings = warning.getvalue().strip()
-    assert warnings == ""
+    # should be one warning:
+    # WARNING: Multiple matches found for 'duplicate':
+    # inter:py:module:duplicate, inter:std:label:duplicate [myst.iref_ambiguous]
+    warnings = warning.getvalue().strip().splitlines()
+    assert len(warnings) == 1
+    assert "[myst.iref_ambiguous]" in warnings[0]
 
     try:
         get_sphinx_app_doctree(app, docname="index", regress=True)
@@ -248,11 +251,14 @@ def test_includes(
             app,
             docname="index",
             regress=True,
+            rstrip_lines=True,
             # fix for Windows CI
             replace={
                 r"subfolder\example2.jpg": "subfolder/example2.jpg",
                 r"subfolder\\example2.jpg": "subfolder/example2.jpg",
                 r"subfolder\\\\example2.jpg": "subfolder/example2.jpg",
+                # in sphinx 5.3 whitespace nodes were added
+                '                <inline classes="whitespace">\n    ': "",
             },
         )
     finally:
@@ -265,14 +271,13 @@ def test_includes(
                 r"'subfolder\\example2'": "'subfolder/example2'",
                 r'uri="subfolder\\example2"': 'uri="subfolder/example2"',
                 "_images/example21.jpg": "_images/example2.jpg",
+                # in sphinx 5.3 whitespace nodes were added
+                '<span class="whitespace"></span>': "",
+                '<span class="whitespace">\n</span>': "\n",
             },
         )
 
 
-@pytest.mark.skipif(
-    __version_info__ < VersionInfo(0, 17, 0, "final", 0, True),
-    reason="parser option added in docutils 0.17",
-)
 @pytest.mark.sphinx(
     buildername="html",
     srcdir=os.path.join(SOURCE_DIR, "include_from_rst"),
@@ -327,7 +332,10 @@ def test_footnotes(
             app,
             filename="footnote_md.html",
             regress_html=True,
-            regress_ext=f".sphinx{sphinx.version_info[0]}.html",
+            regress_ext=".html",
+            replace={
+                'role="note">': 'role="doc-footnote">',  # changed in docutils 0.20
+            },
         )
 
 
@@ -448,7 +456,7 @@ def test_gettext_html(
         app,
         filename="index.html",
         regress_html=True,
-        regress_ext=f".sphinx{sphinx.version_info[0]}.html",
+        regress_ext=".html",
     )
 
 
@@ -530,13 +538,18 @@ def test_fieldlist_extension(
             app,
             docname="index",
             regress=True,
-            # changed in:
-            # https://www.sphinx-doc.org/en/master/changes.html#release-4-4-0-released-jan-17-2022
             replace={
+                # changed in:
+                # https://www.sphinx-doc.org/en/master/changes.html#release-4-4-0-released-jan-17-2022
                 (
                     '<literal_strong py:class="True" '
                     'py:module="True" refspecific="True">'
-                ): "<literal_strong>"
+                ): "<literal_strong>",
+                # changed in sphinx 5.3, for `desc` node
+                'nocontentsentry="False" ': "",
+                'noindexentry="False" ': "",
+                # changed in sphinx 5.3, for `desc_signature` node
+                '_toc_name="send_message()" _toc_parts="(\'send_message\',)" ': "",
             },
         )
     finally:
@@ -544,21 +557,17 @@ def test_fieldlist_extension(
             app,
             filename="index.html",
             regress_html=True,
-            regress_ext=f".sphinx{sphinx.version_info[0]}.html",
+            regress_ext=".html",
         )
 
 
 @pytest.mark.sphinx(
     buildername="texinfo",
-    srcdir=os.path.join(SOURCE_DIR, "texi_table"),
+    srcdir=os.path.join(SOURCE_DIR, "texinfo"),
     freshenv=True,
 )
-def test_texinfo_table(
-    app,
-    status,
-    warning,
-):
-    """Test that tables can be built with the Texinfo builder."""
+def test_texinfo(app, status, warning):
+    """Test Texinfo builds."""
     app.build()
     assert "build succeeded" in status.getvalue()  # Build succeeded
     warnings = warning.getvalue().strip()
